/*
 * Copyright 2017-2024 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package example.micronaut;

import io.micronaut.http.client.HttpClient;
import io.micronaut.http.client.annotation.Client;
import io.micronaut.test.extensions.junit5.annotation.MicronautTest;
import org.junit.jupiter.api.Test;

import java.io.IOException;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

@MicronautTest // <1>
class StaticResourceTest {

    @Test
    void stylesheetExists(@Client("/css") HttpClient client) { // <2>
        String css = client.toBlocking().retrieve("/style.css", String.class);
        assertTrue(css.contains("""
                html, body {"""));
    }

    @Test
    void imageExists(@Client("/images") HttpClient client) throws IOException { // <2>
        byte[] image = client.toBlocking().retrieve("/micronaut_stacked_black.png", byte[].class);
        int expectedLength = StaticResourceTest.class
                .getResourceAsStream("/static/images/micronaut_stacked_black.png")
                .readAllBytes().length;
        assertEquals(expectedLength, image.length);
    }
}
